/*
 * logger.js
 * Copyright  2007 Tommi Rautava
 * 
 * This file is part of Popomungo.
 *
 * Popomungo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Popomungo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

var pm_Logger = {

	// Debug mode: 0=off, 1=on
	traceLevel: 1,
	
	
	// Console Service
	_consoleService: Components.classes['@mozilla.org/consoleservice;1']
		.getService(Components.interfaces.nsIConsoleService),
		
	
	/*
	 * Send message to console.
	 * 
	 * @param message
	 */
	log: function log(message) {
		var myCaller = this.log.caller.name;
		
		this._consoleService.logStringMessage(
			'Popomungo:'+ myCaller +': ' + message);
	},

	/*
	 * Send error message to console.
	 * 
	 * @param message
	 */
	logError: function logError(message) {
		var myCaller = this.logError.caller.name;

		var msg = 'Popomungo:'+ myCaller +': ' + message;

		// Is exception?				
		if (message.stack) {
 			msg = msg +':\n'+ message.stack;
		}
		
		Components.utils.reportError(
			'Popomungo:'+ myCaller +': ' + msg);

		if (pm_Prefs.getPref(pm_PrefKeys.ALERT_ON_ERROR, false)) {
			alert(myCaller +":\n"+ msg);
		}
	},
	
	
	/*
	 * Send info message to console.
	 * 
	 * @param message
	 * @see traceLevel
	 */
	debug: function debug(message) {
		if (pm_Logger.traceLevel > 0) {
			var myCaller = this.debug.caller.name;

			this._consoleService.logStringMessage(
				'Popomungo:'+ myCaller +': ' + message);
		}
	},

	
	debugObject: function debugObject(obj, objName) {
		if (pm_Logger.traceLevel > 0) {
			var myCaller = this.debugObject.caller.name;

			var message = '';
			if (obj) {
				for (var i in obj) {
					message = message + i +'='+ obj[i] +'\n';
				}
				
				message = '\n'+ message;
			} else {
				message = obj;
			}
				
			this._consoleService.logStringMessage(
				'Popomungo:'+ myCaller +': '+ (objName ? objName +'=' : '') + message);
		}
	},
	
	
	getTraceLevel:
	function getTraceLevel() {
		return this.traceLevel;
	},
	
	
	setTraceLevelFromPref:
	function setTraceLevelFromPref() {
		var pref = Components.classes["@mozilla.org/preferences-service;1"].
			getService(Components.interfaces.nsIPrefService).
			getBranch(pm_CommonConstants.PREF_BRANCH);
		
		this.traceLevel = pref.getIntPref(pm_PrefKeys.TRACE_LEVEL);
		
		if (this.traceLevel != 0) {
			this._consoleService.logStringMessage(
					'Popomungo:setTraceLevelFromPref: traceLevel='+ this.traceLevel);
		}
	}
};

pm_Logger.setTraceLevelFromPref();
